package main

import (
	"fmt"
	"github.com/nats-io/nats.go"
	"log"
	"os"
	"time"
)

func main() {
	nc, err := nats.Connect(os.Getenv("NATS_SERVER_URL"))
	if err != nil {
		log.Panic(err)
	}

	defer nc.Drain()

	subscribe(nc, "normal_subscriber", "foo.1")
	subscribe(nc, "wildcard_subscriber", "foo.*")
	ticker := time.NewTicker(5 * time.Second)

	for {
		select {
		case <-ticker.C:
			err = nc.Publish("foo.1", []byte("Hello World"))
			if err != nil {
				log.Panic(err)
			}

			err = nc.Publish("foo.2", []byte("Hello World"))
			if err != nil {
				log.Panic(err)
			}
		}
	}

}

func subscribe(client *nats.Conn, name, subject string) {
	_, err := client.Subscribe(subject, func(msg *nats.Msg) {
		fmt.Printf("sub %s: received message %q\n", name, msg.Subject)
	})

	if err != nil {
		log.Panic(err)
	}
}
